@@ -12,20 +12,6 @@ from i2.wrapper import Ingress, wrap
 ignore_import_problems = suppress(ImportError, ModuleNotFoundError)
 
 
-def partialx(func, *args, __name__=None, rm_partialize=False, **kwargs):
-    """Same as functools.partial, but with a __name__"""
-    f = partial(func, *args, **kwargs)
-    if rm_partialize:
-        sig = Sig(func)
-        partialized = list(
-            sig.kwargs_from_args_and_kwargs(args, kwargs, allow_partial=True)
-        )
-        sig = sig - partialized
-        f = sig(partial(f, *args, **kwargs))
-    f.__name__ = __name__ or func.__name__
-    return f
-
-
 def iterable_to_enum(iterable, name='CustomEnum'):
     return Enum(name, {str(kv): kv for kv in iterable})
 
